world.RdGet the borders for all the countries in the world. Data are read from files that are downloaded if necessary.
world(resolution=5, level=0, path, version="latest", ...)integer between 1 and 5 indicating the level of detail. 1 is high 5 is low
numeric. The level of administrative subdivision requested. (starting with 0 for country, then 1 for the first level of subdivision). Only level 0 is currently available
character. Path for storing the downloaded data. See geodata_path
character. Only "3.6" is currently supported
additional arguments passed to download.file
SpatVector
The data are from https://gadm.org
w <- world(path=tempdir())
#> Cached as: /tmp/Rtmpj1ul8r/gadm/gadm36_adm0_r5_pk.rds