elevation.RdElevation data for any country. The main data source is Shuttle Radar Topography Mission (SRTM) , specifically the hole-filled CGIAR-SRTM (90 m resolution) from https://srtm.csi.cgiar.org/. These data are only available for latitudes between -60 and 60.
The 1 km (30 arc seconds) data were aggregated from SRTM 90 m resolution data and supplemented with the GTOP30 data for high latitudes (>60 degrees).
elevation_3s(lon, lat, path, ...)
elevation_30s(country, path, mask=TRUE, subs="", ...)
elevation_global(res, path, ...)numeric. Longitude
numeric. Latitude
character. Path for storing the downloaded data. See geodata_path
character. Country name or code
logical. set grid cells outside of the country boundaries to NA
character
numeric. Valid resolutions are 10, 5, 2.5, and 0.5 (minutes of a degree)
additional arguments passed to download.file
SpatRaster
be <- elevation_30s(country="BEL", path=tempdir() )
#> Cached as: /tmp/Rtmpj1ul8r/elevation/BEL_elv_msk.zip