geodata_path.RdThis function allows you set or get the default download cache path for the geodata package. The default path is ignored if you set the path argument in a geodata function to another value.
A special value is "user_data_dir". This sets it to the location returned by file.path(rappdirs::user_data_dir(), "geodata")
Alternatively, you can also set a system variable "GEODATA_PATH" to the desired path.
geodata_path(path, persistent=TRUE)character
geodata_path()
#> [1] ""